@@ -102,27 +102,35 @@ class KitsuAPIWrapper(flow.Object):
             target_tasks = defaultdict(list)
             
             for type_name, statutes in task_status_filters.items():
-                type_id = gazu.task.get_task_type_by_name(type_name)['id']
-                
-                for status_name in statutes:
-                    status_id = gazu.task.get_task_status_by_name(status_name)['id']
-                    target_tasks[type_id].append(status_id)
-            
-            for t in gazu.task.all_tasks_for_project(self.get_project_id()):
-                if t['task_type_id'] not in target_tasks:
+                task_type = gazu.task.get_task_type_by_name(type_name)
+
+                if task_type is None:
                     continue
                 
-                shot_id = t['entity_id']
-                has_valid_status = False
+                for status_name in statutes:
+                    task_status = gazu.task.get_task_status_by_name(status_name)
 
-                # Loop over statutes
-                for status_id in target_tasks[t['task_type_id']]:
-                    if status_id == t['task_status_id']:
-                        has_valid_status = True
-                        break
-                
-                if has_valid_status:
-                    shots.append(gazu.shot.get_shot(shot_id))
+                    if task_status is None:
+                        continue
+
+                    target_tasks[task_type['id']].append(task_status['id'])
+            
+            if target_tasks:
+                for t in gazu.task.all_tasks_for_project(self.get_project_id()):
+                    if t['task_type_id'] not in target_tasks:
+                        continue
+                    
+                    shot_id = t['entity_id']
+                    has_valid_status = False
+
+                    # Loop over statutes
+                    for status_id in target_tasks[t['task_type_id']]:
+                        if status_id == t['task_status_id']:
+                            has_valid_status = True
+                            break
+                    
+                    if has_valid_status:
+                        shots.append(gazu.shot.get_shot(shot_id))
         else:
             shots = gazu.shot.all_shots_for_project(
                 self.get_project_id()
